"""
A package intended for use with setuptools that determines the package version
number by parsing the commit specifier from a VCS URL in a requirements.txt
file.
This works assuming a convention that the repository will be tagged as the
version number and that URL will have the tag as the specifier.
"""
from requirements import parse

REQFILE = open("requirements.txt")

def get_version(name, reqfile=REQFILE):
    """
    Given the name of the package and requirements file, determine the
    package version.
    """

    requirements = parse(reqfile)

    for requirement in requirements:
        if name == requirement.name:
            return requirement.revision

    return None




from setuptools import (
    find_packages,
    setup
)

setup(
    author="Daniel Brownridge",
    author_email="daniel@freshnewpage.com",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Software Development :: Version Control :: Git",
    ],
    description="Extract package version from requirements.txt VCS URLs",
    install_requires=[
        "requirements-parser"
    ],
    license="MIT",
    name="setuptools-requirements-vcs-version",
    packages=find_packages("src"),
    package_dir={"":"src"},
    url="https://github.com/danielbrownridge/setuptools-requirements-vcs-version",
    version="0.0.3",
)
